@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2017-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2017-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -15,9 +15,7 @@ ImportImapSettingsAkonadiPassword::ImportImapSettingsAkonadiPassword(QObject *pa
 {
 }
 
-ImportImapSettingsAkonadiPassword::~ImportImapSettingsAkonadiPassword()
-{
-}
+ImportImapSettingsAkonadiPassword::~ImportImapSettingsAkonadiPassword() = default;
 
 void ImportImapSettingsAkonadiPassword::readSieveServerPasswordFinished(QKeychain::Job *baseJob)
 {
